==> saint-2.0.2.tgz: saint/html/saint.pl <==
print <<EOF
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 3.2//EN">
<HTML>

<HEAD>
	<META HTTP-EQUIV="Content-Type" CONTENT="text/html;CHARSET=iso-8859-1">
	<META NAME="GENERATOR" Content="Visual Page 2.0 for Windows">
	<TITLE>SAINT</TITLE>
</HEAD>

<BODY BGCOLOR="white">

<P></P>

<P>
<TABLE BORDER="0" CELLPADDING="0" CELLSPACING="0">
	<TR>
		<TD COLSPAN="2"><IMG SRC="$HTML_ROOT/images/SAINT-home-banner.gif" WIDTH="621" HEIGHT="106" ALIGN="BOTTOM" ALT="SAINT home" BORDER="0"></TD>
	</TR>
	<TR>
	  <TD WIDTH="86" VALIGN="TOP">
	    <TABLE BORDER="0" CELLPADDING="0" CELLSPACING="0">
		<TR>
		    <TD WIDTH="86"><A HREF="http://www.wwdsi.com"><IMG SRC="$HTML_ROOT/images/wwdsi_logo.gif" WIDTH="86" HEIGHT="55" ALIGN="BOTTOM" ALT="WWDSI"
			BORDER="0"></A></TD>
		</TR>
		<TR>
		    <TD WIDTH="86"><IMG SRC="$HTML_ROOT/images/home_button.gif" WIDTH="86" HEIGHT="46"
			ALIGN="BOTTOM" ALT="SAINT Home" BORDER="0" STYLE="Background-Image : none"></TD>
		</TR>
		<TR>
		    <TD WIDTH="86"><A HREF="$HTML_SERVER/data/saint_data_form.pl"><IMG SRC="$HTML_ROOT/images/data_mgmt_button.gif" WIDTH="86"
			HEIGHT="46" ALIGN="BOTTOM" ALT="Data Management" BORDER="0"></A></TD>
		</TR>
		<TR>
		    <TD WIDTH="86"><A HREF="$HTML_SERVER/running/saint_run_form.pl"><IMG SRC="$HTML_ROOT/images/target_selection_button.gif"
			WIDTH="86" HEIGHT="46" ALIGN="BOTTOM" ALT="Target Selection" BORDER="0"></A></TD>
		</TR>
		<TR>
		    <TD WIDTH="86"><A HREF="$HTML_SERVER/reporting/analysis.pl"><IMG SRC="$HTML_ROOT/images/data_analysis_button.gif" WIDTH="86"
			HEIGHT="46" ALIGN="BOTTOM" ALT="Data Analysis" BORDER="0"></A></TD>
		</TR>
		<TR>
		    <TD WIDTH="86"><A HREF="$HTML_SERVER/admin/saint_cf_form.pl"><IMG SRC="$HTML_ROOT/images/config_mgmt_button.gif" WIDTH="86"
			HEIGHT="46" ALIGN="BOTTOM" ALT="Configuration Management" BORDER="0"></A></TD>
		</TR>
		<TR>
		    <TD WIDTH="86"><A HREF="$HTML_ROOT/saint_documentation.html"><IMG SRC="$HTML_ROOT/images/documentation_button.gif"
			WIDTH="86" HEIGHT="46" ALIGN="BOTTOM" ALT="SAINT Documentation" BORDER="0"></A></TD>
		</TR>
		<TR>
		    <TD WIDTH="86" HEIGHT="46"><A HREF="$HTML_ROOT/docs/FAQ.html#trouble"><IMG SRC="$HTML_ROOT/images/troubleshooting_button.gif" WIDTH="86"
			HEIGHT="46" ALIGN="BOTTOM" ALT="Troubleshooting" BORDER="0"></A></TD>
		</TR>
		<TR>
		    <TD WIDTH="86" HEIGHT="65"><IMG SRC="$HTML_ROOT/images/bottom_border.gif" WIDTH="86" HEIGHT="75" ALIGN="BOTTOM" ALT="--------" BORDER="0"></TD>
		</TR>
	    </TABLE>
	  </TD>
	  <TD VALIGN="TOP">
		<DL>
			<P>
		</DL>
			<BLOCKQUOTE>
				<P><SPAN STYLE="Margin-Bottom : 0px    ; Margin-Top : 0px    ; Padding-Bottom : 0px    ; Padding-Left : 0px    ; Padding-Right : 0px    ; Padding-Top : 0px"><FONT
				COLOR="navy">The Security Administrator's Integrated Network<BR>
				<BR>
				Tool (SAINT) is designed to assess the security<BR>
				<BR>
				of computer networks. SAINT is a highly evolved<BR>
				<BR>
				version of its predecessor </FONT></SPAN><A HREF="http://www.fish.com/satan/"><SPAN STYLE="Margin-Bottom : 0px    ; Margin-Top : 0px    ; Padding-Bottom : 0px    ; Padding-Left : 0px    ; Padding-Right : 0px    ; Padding-Top : 0px"><FONT
				COLOR="#3366FF">SATAN</FONT></SPAN></A><SPAN STYLE="Margin-Bottom : 0px    ; Margin-Top : 0px    ; Padding-Bottom : 0px    ; Padding-Left : 0px    ; Padding-Right : 0px    ; Padding-Top : 0px"><FONT
				COLOR="#3366FF">. </FONT></SPAN><SPAN STYLE="Margin-Bottom : 0px    ; Margin-Top : 0px    ; Padding-Bottom : 0px    ; Padding-Left : 0px    ; Padding-Right : 0px    ; Padding-Top : 0px"><FONT
				 COLOR="navy">SAINT is <BR>
				<BR>
				indispensable for checking system vulnerabilities. 
				<TABLE ALIGN="LEFT" BORDER="0" CELLPADDING="0" CELLSPACING="0" WIDTH="423" HEIGHT="75">
					<TR>
						<TD WIDTH="19" HEIGHT="32">&nbsp;</TD>
						<TD WIDTH="404" HEIGHT="32">&nbsp;</TD>
					</TR>
					<TR>
						<TD WIDTH="19" HEIGHT="20" VALIGN="TOP">
							<P ALIGN="RIGHT"><IMG SRC="images/bullet.gif" WIDTH="19" HEIGHT="20" ALIGN="BOTTOM" BORDER="0">
						</TD>
						<TD WIDTH="404" HEIGHT="20" VALIGN="TOP"><A HREF="http://www.wwdsi.com/saint/"><FONT COLOR="#3366FF">Getting the Latest Version
							of SAINT</FONT></A></TD>
					</TR>
					<TR>
						<TD WIDTH="19">&nbsp;</TD>
						<TD WIDTH="404">&nbsp;</TD>
					</TR>
					<TR>
						<TD WIDTH="19" HEIGHT="20" VALIGN="TOP">
							<P ALIGN="RIGHT"><IMG SRC="images/bullet.gif" WIDTH="19" HEIGHT="20" ALIGN="BOTTOM" BORDER="0">
						</TD>
						<TD WIDTH="404" HEIGHT="20" VALIGN="TOP"><A HREF="docs/FAQ.html#cve"><FONT COLOR="#3366FF">SAINT includes
							CVE numbers</FONT></A><BR><A HREF="docs/cve.html"><FONT COLOR="#3366FF">(Which CVEs can SAINT detect?)</FONT></A>
						</TD>
					</TR>
					<TR>
						<TD WIDTH="19">&nbsp;</TD>
						<TD WIDTH="404">&nbsp;</TD>
					</TR>
					<TR>
						<TD WIDTH="19" HEIGHT="35" VALIGN="TOP">
							<P ALIGN="RIGHT"><IMG SRC="images/bullet.gif" WIDTH="19" HEIGHT="20" ALIGN="BOTTOM" BORDER="0">
						</TD>
						<TD WIDTH="404" HEIGHT="35" VALIGN="TOP"><A HREF="docs/authors.html"><FONT COLOR="#3366FF">About the
							SAINT Team</FONT></A></TD>
					</TR>
				</TABLE>
</FONT></SPAN>
			</BLOCKQUOTE>
	  </TD>
	</TR>
</TABLE>
</BODY>
EOF

==> saint-2.2.tgz: saint/html/saint.pl <==
print <<EOF
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 3.2//EN">
<HTML>

<HEAD>
	<META HTTP-EQUIV="Content-Type" CONTENT="text/html;CHARSET=iso-8859-1">
	<META NAME="GENERATOR" Content="Visual Page 2.0 for Windows">
	<TITLE>SAINT</TITLE>
</HEAD>

<BODY BGCOLOR="white">

<P></P>

<P>
<TABLE BORDER="0" CELLPADDING="0" CELLSPACING="0">
	<TR>
		<TD COLSPAN="2"><IMG SRC="$HTML_ROOT/images/SAINT-home-banner.gif" WIDTH="621" HEIGHT="106" ALIGN="BOTTOM" ALT="SAINT home" BORDER="0"></TD>
	</TR>
	<TR>
	  <TD WIDTH="86" VALIGN="TOP">
	    <TABLE BORDER="0" CELLPADDING="0" CELLSPACING="0">
		<TR>
		    <TD WIDTH="86"><A HREF="http://www.wwdsi.com"><IMG SRC="$HTML_ROOT/images/wwdsi_logo.gif" WIDTH="86" HEIGHT="55" ALIGN="BOTTOM" ALT="WWDSI"
			BORDER="0"></A></TD>
		</TR>
		<TR>
		    <TD WIDTH="86"><IMG SRC="$HTML_ROOT/images/home_button.gif" WIDTH="86" HEIGHT="46"
			ALIGN="BOTTOM" ALT="SAINT Home" BORDER="0" STYLE="Background-Image : none"></TD>
		</TR>
		<TR>
		    <TD WIDTH="86"><A HREF="$HTML_SERVER/data/saint_data_form.pl"><IMG SRC="$HTML_ROOT/images/data_mgmt_button.gif" WIDTH="86"
			HEIGHT="46" ALIGN="BOTTOM" ALT="Data Management" BORDER="0"></A></TD>
		</TR>
		<TR>
		    <TD WIDTH="86"><A HREF="$HTML_SERVER/running/saint_run_form.pl"><IMG SRC="$HTML_ROOT/images/target_selection_button.gif"
			WIDTH="86" HEIGHT="46" ALIGN="BOTTOM" ALT="Target Selection" BORDER="0"></A></TD>
		</TR>
		<TR>
		    <TD WIDTH="86"><A HREF="$HTML_SERVER/reporting/analysis.pl"><IMG SRC="$HTML_ROOT/images/data_analysis_button.gif" WIDTH="86"
			HEIGHT="46" ALIGN="BOTTOM" ALT="Data Analysis" BORDER="0"></A></TD>
		</TR>
		<TR>
		    <TD WIDTH="86"><A HREF="$HTML_SERVER/admin/saint_cf_form.pl"><IMG SRC="$HTML_ROOT/images/config_mgmt_button.gif" WIDTH="86"
			HEIGHT="46" ALIGN="BOTTOM" ALT="Configuration Management" BORDER="0"></A></TD>
		</TR>
		<TR>
		    <TD WIDTH="86"><A HREF="$HTML_ROOT/saint_documentation.html"><IMG SRC="$HTML_ROOT/images/documentation_button.gif"
			WIDTH="86" HEIGHT="46" ALIGN="BOTTOM" ALT="SAINT Documentation" BORDER="0"></A></TD>
		</TR>
		<TR>
		    <TD WIDTH="86" HEIGHT="46"><A HREF="$HTML_ROOT/docs/FAQ.html#trouble"><IMG SRC="$HTML_ROOT/images/troubleshooting_button.gif" WIDTH="86"
			HEIGHT="46" ALIGN="BOTTOM" ALT="Troubleshooting" BORDER="0"></A></TD>
		</TR>
		<TR>
		    <TD WIDTH="86" HEIGHT="65"><IMG SRC="$HTML_ROOT/images/bottom_border.gif" WIDTH="86" HEIGHT="75" ALIGN="BOTTOM" ALT="--------" BORDER="0"></TD>
		</TR>
	    </TABLE>
	  </TD>
	  <TD VALIGN="TOP">
		<DL>
			<P>
		</DL>
			<BLOCKQUOTE>
				<P><SPAN STYLE="Margin-Bottom : 0px    ; Margin-Top : 0px    ; Padding-Bottom : 0px    ; Padding-Left : 0px    ; Padding-Right : 0px    ; Padding-Top : 0px"><FONT
				COLOR="navy">The Security Administrator's Integrated Network<BR>
				<BR>
				Tool (SAINT) is designed to assess the security<BR>
				<BR>
				of computer networks. SAINT is a highly evolved<BR>
				<BR>
				version of its predecessor </FONT></SPAN><A HREF="http://www.fish.com/satan/"><SPAN STYLE="Margin-Bottom : 0px    ; Margin-Top : 0px    ; Padding-Bottom : 0px    ; Padding-Left : 0px    ; Padding-Right : 0px    ; Padding-Top : 0px"><FONT
				COLOR="#3366FF">SATAN</FONT></SPAN></A><SPAN STYLE="Margin-Bottom : 0px    ; Margin-Top : 0px    ; Padding-Bottom : 0px    ; Padding-Left : 0px    ; Padding-Right : 0px    ; Padding-Top : 0px"><FONT
				COLOR="#3366FF">. </FONT></SPAN><SPAN STYLE="Margin-Bottom : 0px    ; Margin-Top : 0px    ; Padding-Bottom : 0px    ; Padding-Left : 0px    ; Padding-Right : 0px    ; Padding-Top : 0px"><FONT
				 COLOR="navy">SAINT is <BR>
				<BR>
				indispensable for checking system vulnerabilities. 
				<TABLE ALIGN="LEFT" BORDER="0" CELLPADDING="0" CELLSPACING="0" WIDTH="423" HEIGHT="75">
					<TR>
						<TD WIDTH="19" HEIGHT="32">&nbsp;</TD>
						<TD WIDTH="404" HEIGHT="32">&nbsp;</TD>
					</TR>
					<TR>
						<TD WIDTH="19" HEIGHT="20" VALIGN="TOP">
							<P ALIGN="RIGHT"><IMG SRC="$HTML_ROOT/images/bullet.gif" WIDTH="19" HEIGHT="20" ALIGN="BOTTOM" BORDER="0">
						</TD>
						<TD WIDTH="404" HEIGHT="20" VALIGN="TOP"><A HREF="http://www.wwdsi.com/saint/"><FONT COLOR="#3366FF">Getting the Latest Version
							of SAINT</FONT></A></TD>
					</TR>
					<TR>
						<TD WIDTH="19">&nbsp;</TD>
						<TD WIDTH="404">&nbsp;</TD>
					</TR>
					<TR>
						<TD WIDTH="19" HEIGHT="20" VALIGN="TOP">
							<P ALIGN="RIGHT"><IMG SRC="$HTML_ROOT/images/bullet.gif" WIDTH="19" HEIGHT="20" ALIGN="BOTTOM" BORDER="0">
						</TD>
						<TD WIDTH="404" HEIGHT="20" VALIGN="TOP"><FONT COLOR="#3366FF">SAINT&#153; includes</FONT><A HREF="$HTML_ROOT/docs/FAQ.html#cve"><FONT COLOR="#3366FF">
							CVE numbers</FONT></A><BR><FONT COLOR="#3366FF"> and scans for the </FONT><A HREF="$HTML_ROOT/docs/FAQ.html#top10"><FONT COLOR="#3366FF">Top 10
							Vulnerabilities</FONT></A><FONT COLOR="#3366FF">.</FONT><BR><A HREF="$HTML_ROOT/docs/cve.html"><FONT COLOR="#3366FF">(Which CVEs can SAINT detect?)</FONT></A>
						</TD>
					</TR>
					<TR>
						<TD WIDTH="19">&nbsp;</TD>
						<TD WIDTH="404">&nbsp;</TD>
					</TR>
					<TR>
						<TD WIDTH="19" HEIGHT="35" VALIGN="TOP">
							<P ALIGN="RIGHT"><IMG SRC="$HTML_ROOT/images/bullet.gif" WIDTH="19" HEIGHT="20" ALIGN="BOTTOM" BORDER="0">
						</TD>
						<TD WIDTH="404" HEIGHT="35" VALIGN="TOP"><A HREF="http://www.wwdsi.com/about/customer_eval.html"><FONT COLOR="#3366FF">
							We'd like to hear from you!</FONT></A></TD>
					</TR>
EOF
;
if ($remote_mode) {
print <<EOF
					<TR>
						<TD WIDTH="19">&nbsp;</TD>
						<TD WIDTH="404"><FORM METHOD=POST ACTION="http://$THIS_HOST:$server_port">
						<INPUT TYPE=hidden NAME=logout VALUE=logout>
						<BLOCKQUOTE><INPUT TYPE=submit VALUE="Log Out"><BLOCKQUOTE>
						</FORM></TD>
					</TR>
EOF
;
}
print <<EOF
				</TABLE>
</FONT></SPAN>
			</BLOCKQUOTE>
	  </TD>
	</TR>
</TABLE>
</BODY>
EOF
